pub struct Caller {
pub id: CredentialId,
}Fields
id: CredentialIdTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Caller
impl<'de> Deserialize<'de> for Caller
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&MessageInfo> for Caller
impl From<&MessageInfo> for Caller
Sourcefn from(info: &MessageInfo) -> Self
fn from(info: &MessageInfo) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for Caller
impl JsonSchema for Caller
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Verifiable for Caller
impl Verifiable for Caller
fn id(&self) -> CredentialId
fn human_id(&self) -> String
fn info(&self) -> CredentialInfo
fn message(&self) -> Binary
fn validate(&self) -> Result<(), AuthError>
fn cosmos_address(&self, _: &dyn Api) -> Result<Addr, AuthError>
fn verify_cosmwasm(&self, _: &dyn Api, _: &Env) -> Result<(), AuthError>
fn message_digest(&self) -> Result<Vec<u8>, AuthError>
fn is_cosmos_derivable(&self) -> bool
fn assert_query_cosmwasm<D>(
&self,
api: &dyn Api,
storage: &dyn Storage,
env: &Env,
_: &Option<MessageInfo>,
) -> Result<String, AuthError>where
D: Serialize + DeserializeOwned,
fn assert_execute_cosmwasm<D>(
&self,
api: &dyn Api,
storage: &mut dyn Storage,
env: &Env,
info: &Option<MessageInfo>,
) -> Result<(), AuthError>where
D: Serialize + DeserializeOwned,
fn save_cosmwasm<D>( &self, api: &dyn Api, storage: &mut dyn Storage, env: &Env, info: &Option<MessageInfo>, ) -> Result<Self, AuthError>
impl StructuralPartialEq for Caller