pub struct EthPersonalSign {
pub message: Binary,
pub signature: Binary,
pub signer: String,
}Fields
message: Binarysignature: Binarysigner: StringTrait Implementations
Sourceimpl Clone for EthPersonalSign
impl Clone for EthPersonalSign
Sourcefn clone(&self) -> EthPersonalSign
fn clone(&self) -> EthPersonalSign
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EthPersonalSign
impl Debug for EthPersonalSign
Sourceimpl<'de> Deserialize<'de> for EthPersonalSign
impl<'de> Deserialize<'de> for EthPersonalSign
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EthPersonalSign
impl JsonSchema for EthPersonalSign
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for EthPersonalSign
impl PartialEq for EthPersonalSign
Sourceimpl Serialize for EthPersonalSign
impl Serialize for EthPersonalSign
Sourceimpl Verifiable for EthPersonalSign
impl Verifiable for EthPersonalSign
fn id(&self) -> CredentialId
fn human_id(&self) -> String
fn info(&self) -> CredentialInfo
fn message(&self) -> Binary
fn validate(&self) -> Result<(), AuthError>
fn message_digest(&self) -> Result<Vec<u8>, AuthError>
fn verify_cosmwasm(&self, api: &dyn Api, _: &Env) -> Result<(), AuthError>
fn cosmos_address(&self, _: &dyn Api) -> Result<Addr, AuthError>
fn is_cosmos_derivable(&self) -> bool
fn assert_query_cosmwasm<D>(
&self,
api: &dyn Api,
storage: &dyn Storage,
env: &Env,
_: &Option<MessageInfo>,
) -> Result<String, AuthError>where
D: Serialize + DeserializeOwned,
fn assert_execute_cosmwasm<D>(
&self,
api: &dyn Api,
storage: &mut dyn Storage,
env: &Env,
info: &Option<MessageInfo>,
) -> Result<(), AuthError>where
D: Serialize + DeserializeOwned,
fn save_cosmwasm<D>( &self, api: &dyn Api, storage: &mut dyn Storage, env: &Env, info: &Option<MessageInfo>, ) -> Result<Self, AuthError>
impl StructuralPartialEq for EthPersonalSign