pub struct EvmCredential {
pub message: Binary,
pub signature: Binary,
pub signer: String,
}Fields
message: Binarysignature: Binarysigner: StringTrait Implementations
sourceimpl Clone for EvmCredential
impl Clone for EvmCredential
sourcefn clone(&self) -> EvmCredential
fn clone(&self) -> EvmCredential
Returns a copy of the value. Read more
1.6.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for EvmCredential
impl Debug for EvmCredential
sourceimpl<'de> Deserialize<'de> for EvmCredential
impl<'de> Deserialize<'de> for EvmCredential
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for EvmCredential
impl JsonSchema for EvmCredential
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq for EvmCredential
impl PartialEq for EvmCredential
sourceimpl Serialize for EvmCredential
impl Serialize for EvmCredential
sourceimpl Verifiable for EvmCredential
impl Verifiable for EvmCredential
impl StructuralPartialEq for EvmCredential