pub struct ClientData {
pub ty: String,
pub challenge: Binary,
pub origin: String,
pub cross_origin: bool,
}Fields
ty: Stringchallenge: Binaryorigin: Stringcross_origin: boolTrait Implementations
Sourceimpl Clone for ClientData
impl Clone for ClientData
Sourcefn clone(&self) -> ClientData
fn clone(&self) -> ClientData
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClientData
impl Debug for ClientData
Sourceimpl<'de> Deserialize<'de> for ClientData
impl<'de> Deserialize<'de> for ClientData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ClientData
impl JsonSchema for ClientData
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ClientData
impl PartialEq for ClientData
Sourceimpl Serialize for ClientData
impl Serialize for ClientData
impl StructuralPartialEq for ClientData