pub struct PasskeyCredential {
pub id: String,
pub signature: Binary,
pub authenticator_data: Binary,
pub client_data: ClientData,
pub user_handle: Option<String>,
pub pubkey: Option<Binary>,
}Fields
id: StringPasskey id
signature: BinarySecp256r1 signature
authenticator_data: Binarywebauthn Authenticator data
client_data: ClientDataClient data containg challenge, origin and type
user_handle: Option<String>Optional user handle reserved for future use
pubkey: Option<Binary>Public key is essential for verification but can be supplied on the contract side and omitted by client
Implementations